#!/bin/bash

# 阿里云镜像站基础URL
ALIYUNMIRROR="http://mirrors.aliyun.com"

# 检测操作系统类型
if grep -q "Debian" /etc/os-release || grep -q "Ubuntu" /etc/os-release; then
    # Debian/Ubuntu系列
    echo "Detected Debian/Ubuntu system. Updating APT sources..."

    # 备份原始sources.list文件
    cp /etc/apt/sources.list /etc/apt/sources.list.bak

    # 替换镜像站URL
    sed -i "s/http:\/\/[^\/]*/$ALIYUNMIRROR/g" /etc/apt/sources.list

    # 更新软件包列表
    apt-get update
elif grep -q "CentOS" /etc/os-release || grep -q "Red Hat" /etc/os-release; then
    # CentOS/RHEL系列
    echo "Detected CentOS/RHEL system. Updating YUM repositories..."

    # 备份原始repo文件
    cp /etc/yum.repos.d/*.repo /etc/yum.repos.d/*.repo.bak

    # 替换镜像站URL
    for FILE in /etc/yum.repos.d/*.repo; do
        sed -i "s/mirrorlist=http:\/\/mirrorlist.centos.org\/releasever\/basearch\/mirrorlist/$ALIYUNMIRROR\/centos\/releasever\/basearch\/g" "$FILE"
        sed -i "s#baseurl=http:\/\/mirror.centos.org\/centos#baseurl=$ALIYUNMIRROR\/centos#g" "$FILE"
    done

    # 清除缓存并生成新的元数据
    yum clean all
    yum makecache
else
    echo "Unsupported OS detected."
    exit 1
fi

echo "Mirror update completed."
